# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 1.8.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr
from public_api_server_connector.models.file_transcription_content_result import FileTranscriptionContentResult
from public_api_server_connector.models.transcription_status import TranscriptionStatus

class FileTranscriptionResult(BaseModel):
    """
    FileTranscriptionResult
    """
    id: StrictInt = Field(default=..., description="Mediastorage database ID of the file, the same ID used to retrieve the file metadata.")
    file_id: StrictStr = Field(default=..., description="Unique file hash identifier that can be used to retrieve the file later")
    file_type: StrictStr = Field(default=..., description="Type of the transcribed media file, either 'video' or 'audio'.")
    status: TranscriptionStatus = Field(default=..., description="Transcription status. The transcription content is only available when the status is 'finished'.")
    file_transcription: Optional[FileTranscriptionContentResult] = Field(default=None, description="Transcription content with full text and timestamped segments. Null unless the status is 'finished'.")
    updated_at: Optional[StrictInt] = Field(default=None, description="Date of the last manual transcription edit in epoch milliseconds. Null if never edited.")
    error_description: Optional[StrictStr] = Field(default=None, description="Error description if the transcription failed, null otherwise.")
    __properties = ["id", "file_id", "file_type", "status", "file_transcription", "updated_at", "error_description"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> FileTranscriptionResult:
        """Create an instance of FileTranscriptionResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of file_transcription
        if self.file_transcription:
            _dict['file_transcription'] = self.file_transcription.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> FileTranscriptionResult:
        """Create an instance of FileTranscriptionResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return FileTranscriptionResult.parse_obj(obj)

        _obj = FileTranscriptionResult.parse_obj({
            "id": obj.get("id"),
            "file_id": obj.get("file_id"),
            "file_type": obj.get("file_type"),
            "status": obj.get("status"),
            "file_transcription": FileTranscriptionContentResult.from_dict(obj.get("file_transcription")) if obj.get("file_transcription") is not None else None,
            "updated_at": obj.get("updated_at"),
            "error_description": obj.get("error_description")
        })
        return _obj


